@@ -2,7 +2,7 @@ use 5.20.0;
 use Map::Metro::Standard;
 
 package Map::Metro {
-$Map::Metro::VERSION = '0.1800';
+$Map::Metro::VERSION = '0.1801';
 use Moose;
     use Module::Pluggable search_path => ['Map::Metro::Plugin::Map'], require => 1, sub_name => 'system_maps';
     use MooseX::AttributeShortcuts;
@@ -95,7 +95,7 @@ use Moose;
     }
 
     sub available_maps($self) {
-        return sort $self->_plugin_locator->plugins;
+        return sort $self->system_maps;
     }
 }
 
